* Generates Table 6 in Desmet, Nagy and Rossi-Hansberg (JPE) 
* September 2016

clear
set memory 1g
global psi=1.8
use AmenitiesCorrelations.dta
log using outputTable6.log, replace

** RECODE SOME VARIABLES
gen famenity_plac=famenity/(exp($psi*ubar))
gen lfamenity=log(famenity)
gen lfamenity_plac=log(famenity_plac)
drop famenity
drop famenity_plac
rename lfamenity famenity
rename lfamenity_plac famenity_plac
replace dis_lake=dis_lake/1000
replace dis_major=dis_major/1000
replace dis_ocean=dis_ocean/1000
replace dis_river=dis_river/1000
gen ldis_ocean=log(1+dis_ocean)
gen mindiswater=min(dis_lake, dis_major, dis_ocean, dis_river)
gen lmindiswater=log(1+mindiswater)
gen lelevation=log(1+elevation)
gen lstdev_elevation=log(1+stdev_elevation)
gen proxwater50=0
replace proxwater50=1 if mindiswater < 50
drop mindiswater
label variable famenity "Fundamental amenity (logs, generated by model)"
label variable famenity_plac "Fundamental amenity assuming utility same across space (logs, generated by model)"
label variable ldis_ocean "Distance to ocean in km (logs)"
label variable lelevation "Log of elevation"
label variable lstdev_elevation "Log of standard deviation of elevation"
label variable proxwater50 "Dummy = 1 if water less than 50 km away"

** ALL CELLS (Table 6, Column 1)

pwcorr famenity ldis_ocean, sig
pwcorr famenity lmindiswater, sig
pwcorr famenity proxwater50, sig
pwcorr famenity lelevation, sig
pwcorr famenity lstdev_elevation, sig
pwcorr famenity prec_new, sig
pwcorr famenity precmax, sig
pwcorr famenity precmin, sig
pwcorr famenity precsd, sig
pwcorr famenity temp_new, sig
pwcorr famenity tempmax, sig
pwcorr famenity tempmin, sig
pwcorr famenity tempsd, sig
gen badland=0
replace badland=1 if mattveg==31
replace badland=1 if mattveg==30
replace badland=1 if mattveg==22
pwcorr famenity badland, sig
** determine optimal maximum temperature (mentioned in text)
gen tempmaxsq=tempmax*tempmax
quiet reg famenity tempmax tempmaxsq
wherext tempmax tempmaxsq

** UNITED STATES (TABLE 6, Column 2)

pwcorr famenity ldis_ocean if country=="United States", sig
pwcorr famenity lmindiswater if country=="United States", sig
pwcorr famenity proxwater50 if country=="United States", sig
pwcorr famenity lelevation if country=="United States", sig
pwcorr famenity lstdev_elevation if country=="United States", sig
pwcorr famenity prec_new if country=="United States", sig
pwcorr famenity precmax if country=="United States", sig
pwcorr famenity precmin if country=="United States", sig
pwcorr famenity precsd if country=="United States", sig
pwcorr famenity temp_new if country=="United States", sig
pwcorr famenity tempmax if country=="United States", sig
pwcorr famenity tempmin if country=="United States", sig
pwcorr famenity tempsd if country=="United States", sig
pwcorr famenity badland if country=="United States", sig

** ONE CELL PER COUNTRY (TABLE 6, Column 3)

capture program drop myboot
program define myboot, rclass
preserve
	bsample 1, strata(country)
	sum famenity
	gen sfamenity=(famenity-r(mean))/r(sd)
	sum ldis_ocean
	gen sldis_ocean=(ldis_ocean-r(mean))/r(sd)
	reg sfamenity sldis_ocean
	restore	
end
set seed 1
bootstrap, reps(5000): myboot

capture program drop myboot
program define myboot, rclass
preserve
	bsample 1, strata(country)
	sum famenity
	gen sfamenity=(famenity-r(mean))/r(sd)
	sum lmindiswater
	gen slmindiswater=(lmindiswater-r(mean))/r(sd)
	reg sfamenity slmindiswater
	restore	
end
set seed 1
bootstrap, reps(5000): myboot

capture program drop myboot
program define myboot, rclass
preserve
	bsample 1, strata(country)
	sum famenity
	gen sfamenity=(famenity-r(mean))/r(sd)
	sum proxwater50
	gen sproxwater50=(proxwater50-r(mean))/r(sd)
	reg sfamenity sproxwater50
	restore	
end
set seed 1
bootstrap, reps(5000): myboot

capture program drop myboot
program define myboot, rclass
preserve
	bsample 1, strata(country)
	sum famenity
	gen sfamenity=(famenity-r(mean))/r(sd)
	sum lelevation
	gen slelevation=(lelevation-r(mean))/r(sd)
	reg sfamenity slelevation
	restore	
end
set seed 1
bootstrap, reps(5000): myboot

capture program drop myboot
program define myboot, rclass
preserve
	bsample 1, strata(country)
	sum famenity
	gen sfamenity=(famenity-r(mean))/r(sd)
	sum lstdev_elevation
	gen slstdev_elevation=(lstdev_elevation-r(mean))/r(sd)
	reg sfamenity slstdev_elevation
	restore	
end
set seed 1
bootstrap, reps(5000): myboot

capture program drop myboot
program define myboot, rclass
preserve
	bsample 1, strata(country)
	sum famenity
	gen sfamenity=(famenity-r(mean))/r(sd)
	sum prec_new
	gen sprec_new=(prec_new-r(mean))/r(sd)
	reg sfamenity sprec_new
	restore	
end
set seed 1
bootstrap, reps(5000): myboot

capture program drop myboot
program define myboot, rclass
preserve
	bsample 1, strata(country)
	sum famenity
	gen sfamenity=(famenity-r(mean))/r(sd)
	sum precmax
	gen sprecmax=(precmax-r(mean))/r(sd)
	reg sfamenity sprecmax
	restore	
end
set seed 1
bootstrap, reps(5000): myboot

capture program drop myboot
program define myboot, rclass
preserve
	bsample 1, strata(country)
	sum famenity
	gen sfamenity=(famenity-r(mean))/r(sd)
	sum precmin
	gen sprecmin=(precmin-r(mean))/r(sd)
	reg sfamenity sprecmin
	restore	
end
set seed 1
bootstrap, reps(5000): myboot

capture program drop myboot
program define myboot, rclass
preserve
	bsample 1, strata(country)
	sum famenity
	gen sfamenity=(famenity-r(mean))/r(sd)
	sum precsd
	gen sprecsd=(precsd-r(mean))/r(sd)
	reg sfamenity sprecsd
	restore	
end
set seed 1
bootstrap, reps(5000): myboot

capture program drop myboot
program define myboot, rclass
preserve
	bsample 1, strata(country)
	sum famenity
	gen sfamenity=(famenity-r(mean))/r(sd)
	sum temp_new
	gen stemp_new=(temp_new-r(mean))/r(sd)
	reg sfamenity stemp_new
	restore	
end
set seed 1
bootstrap, reps(5000): myboot


capture program drop myboot
program define myboot, rclass
preserve
	bsample 1, strata(country)
	sum famenity
	gen sfamenity=(famenity-r(mean))/r(sd)
	sum tempmax
	gen stempmax=(tempmax-r(mean))/r(sd)
	reg sfamenity stempmax
	restore	
end
set seed 1
bootstrap, reps(5000): myboot

capture program drop myboot
program define myboot, rclass
preserve
	bsample 1, strata(country)
	sum famenity
	gen sfamenity=(famenity-r(mean))/r(sd)
	sum tempmin
	gen stempmin=(tempmin-r(mean))/r(sd)
	reg sfamenity stempmin
	restore	
end
set seed 1
bootstrap, reps(5000): myboot

capture program drop myboot
program define myboot, rclass
preserve
	bsample 1, strata(country)
	sum famenity
	gen sfamenity=(famenity-r(mean))/r(sd)
	sum tempsd
	gen stempsd=(tempsd-r(mean))/r(sd)
	reg sfamenity stempsd
	restore	
end
set seed 1
bootstrap, reps(5000): myboot

capture program drop myboot
program define myboot, rclass
preserve
	bsample 1, strata(country)
	sum famenity
	gen sfamenity=(famenity-r(mean))/r(sd)
	sum badland
	gen sbadland=(badland-r(mean))/r(sd)
	reg sfamenity sbadland
	restore	
end
set seed 1
bootstrap, reps(5000): myboot

** PLACEBO ALL CELLS (Table 6, Column 4)

pwcorr famenity_plac ldis_ocean, sig
pwcorr famenity_plac lmindiswater, sig
pwcorr famenity_plac proxwater50, sig
pwcorr famenity_plac lelevation, sig
pwcorr famenity_plac lstdev_elevation, sig
pwcorr famenity_plac prec_new, sig
pwcorr famenity_plac precmax, sig
pwcorr famenity_plac precmin, sig
pwcorr famenity_plac precsd, sig
pwcorr famenity_plac temp_new, sig
pwcorr famenity_plac tempmax, sig
pwcorr famenity_plac tempmin, sig
pwcorr famenity_plac tempsd, sig
pwcorr famenity_plac badland, sig

** PLACEBO ONE CELL PER COUNTRY (TABLE 6, Column 5)

capture program drop myboot
program define myboot, rclass
preserve
	bsample 1, strata(country)
	sum famenity_plac
	gen sfamenity_plac=(famenity_plac-r(mean))/r(sd)
	sum ldis_ocean
	gen sldis_ocean=(ldis_ocean-r(mean))/r(sd)
	reg sfamenity_plac sldis_ocean
	restore	
end
set seed 1
bootstrap, reps(5000): myboot

capture program drop myboot
program define myboot, rclass
preserve
	bsample 1, strata(country)
	sum famenity_plac
	gen sfamenity_plac=(famenity_plac-r(mean))/r(sd)
	sum lmindiswater
	gen slmindiswater=(lmindiswater-r(mean))/r(sd)
	reg sfamenity_plac slmindiswater
	restore	
end
set seed 1
bootstrap, reps(5000): myboot

capture program drop myboot
program define myboot, rclass
preserve
	bsample 1, strata(country)
	sum famenity_plac
	gen sfamenity_plac=(famenity_plac-r(mean))/r(sd)
	sum proxwater50
	gen sproxwater50=(proxwater50-r(mean))/r(sd)
	reg sfamenity_plac sproxwater50
	restore	
end
set seed 1
bootstrap, reps(5000): myboot

capture program drop myboot
program define myboot, rclass
preserve
	bsample 1, strata(country)
	sum famenity_plac
	gen sfamenity_plac=(famenity_plac-r(mean))/r(sd)
	sum lelevation
	gen slelevation=(lelevation-r(mean))/r(sd)
	reg sfamenity_plac slelevation
	restore	
end
set seed 1
bootstrap, reps(5000): myboot

capture program drop myboot
program define myboot, rclass
preserve
	bsample 1, strata(country)
	sum famenity_plac
	gen sfamenity_plac=(famenity_plac-r(mean))/r(sd)
	sum lstdev_elevation
	gen slstdev_elevation=(lstdev_elevation-r(mean))/r(sd)
	reg sfamenity_plac slstdev_elevation
	restore	
end
set seed 1
bootstrap, reps(5000): myboot

capture program drop myboot
program define myboot, rclass
preserve
	bsample 1, strata(country)
	sum famenity_plac
	gen sfamenity_plac=(famenity_plac-r(mean))/r(sd)
	sum prec_new
	gen sprec_new=(prec_new-r(mean))/r(sd)
	reg sfamenity_plac sprec_new
	restore	
end
set seed 1
bootstrap, reps(5000): myboot

capture program drop myboot
program define myboot, rclass
preserve
	bsample 1, strata(country)
	sum famenity_plac
	gen sfamenity_plac=(famenity_plac-r(mean))/r(sd)
	sum precmax
	gen sprecmax=(precmax-r(mean))/r(sd)
	reg sfamenity_plac sprecmax
	restore	
end
set seed 1
bootstrap, reps(5000): myboot

capture program drop myboot
program define myboot, rclass
preserve
	bsample 1, strata(country)
	sum famenity_plac
	gen sfamenity_plac=(famenity_plac-r(mean))/r(sd)
	sum precmin
	gen sprecmin=(precmin-r(mean))/r(sd)
	reg sfamenity_plac sprecmin
	restore	
end
set seed 1
bootstrap, reps(5000): myboot

capture program drop myboot
program define myboot, rclass
preserve
	bsample 1, strata(country)
	sum famenity_plac
	gen sfamenity_plac=(famenity_plac-r(mean))/r(sd)
	sum precsd
	gen sprecsd=(precsd-r(mean))/r(sd)
	reg sfamenity_plac sprecsd
	restore	
end
set seed 1
bootstrap, reps(5000): myboot

capture program drop myboot
program define myboot, rclass
preserve
	bsample 1, strata(country)
	sum famenity_plac
	gen sfamenity_plac=(famenity_plac-r(mean))/r(sd)
	sum temp_new
	gen stemp_new=(temp_new-r(mean))/r(sd)
	reg sfamenity_plac stemp_new
	restore	
end
set seed 1
bootstrap, reps(5000): myboot

capture program drop myboot
program define myboot, rclass
preserve
	bsample 1, strata(country)
	sum famenity_plac
	gen sfamenity_plac=(famenity_plac-r(mean))/r(sd)
	sum tempmax
	gen stempmax=(tempmax-r(mean))/r(sd)
	reg sfamenity_plac stempmax
	restore	
end
set seed 1
bootstrap, reps(5000): myboot

capture program drop myboot
program define myboot, rclass
preserve
	bsample 1, strata(country)
	sum famenity_plac
	gen sfamenity_plac=(famenity_plac-r(mean))/r(sd)
	sum tempmin
	gen stempmin=(tempmin-r(mean))/r(sd)
	reg sfamenity_plac stempmin
	restore	
end
set seed 1
bootstrap, reps(5000): myboot

capture program drop myboot
program define myboot, rclass
preserve
	bsample 1, strata(country)
	sum famenity_plac
	gen sfamenity_plac=(famenity_plac-r(mean))/r(sd)
	sum tempsd
	gen stempsd=(tempsd-r(mean))/r(sd)
	reg sfamenity_plac stempsd
	restore	
end
set seed 1
bootstrap, reps(5000): myboot

capture program drop myboot
program define myboot, rclass
preserve
	bsample 1, strata(country)
	sum famenity_plac
	gen sfamenity_plac=(famenity_plac-r(mean))/r(sd)
	sum badland
	gen sbadland=(badland-r(mean))/r(sd)
	reg sfamenity_plac sbadland
	restore	
end
set seed 1
bootstrap, reps(5000): myboot

log close

